@@ -23,9 +23,13 @@ int main()
 
     // setup suites
     SRunner *runner = srunner_create(cjose_suite());
+
+    srunner_set_fork_status(runner, CK_NOFORK);
+
     srunner_add_suite(runner, cjose_version_suite());
     srunner_add_suite(runner, cjose_util_suite());
     srunner_add_suite(runner, cjose_base64_suite());
+    srunner_add_suite(runner, cjose_concatkdf_suite());
     srunner_add_suite(runner, cjose_jwk_suite());
     srunner_add_suite(runner, cjose_jwe_suite());
     srunner_add_suite(runner, cjose_jws_suite());
@@ -39,7 +43,5 @@ int main()
     EVP_cleanup();
     ERR_free_strings();
 
-    return (0 == failed) ?
-           EXIT_SUCCESS :
-           EXIT_FAILURE;
+    return (0 == failed) ? EXIT_SUCCESS : EXIT_FAILURE;
 }
